# Queries for tournaments.py

PLAYER_ID_QUERY = """query EventEntrants($eventId: ID!, $name: String!) {
    event(id: $eventId) {
    entrants(query: {
      page: 1
      perPage: 32
      filter: {name: $name}
    }) {
      nodes {
        participants {
          gamerTag
          player {
            id 
          }
        }
      }
    }
    }
    }"""

EVENT_ID_QUERY = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      id
      slug
    }
  }
}"""

ENTRANT_ID_QUERY = """query EventEntrants($eventId: ID!, $name: String!) {
    event(id: $eventId) {
    entrants(query: {
      page: 1
      perPage: 32
      filter: {
        name: $name
      }
    }) {
      nodes {
        id
        name
      }
    }
    }
    }"""

SHOW_QUERY = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    id
    name
    countryCode
    addrState
    city
    startAt
    endAt
    numAttendees
  }
}"""


SHOW_WITH_BRACKETS_QUERY = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    id
    name
    countryCode
    addrState
    city
    startAt
    endAt
    numAttendees
    events {
      id
      name
      slug
      phaseGroups {
        id
      }
    }
  }
}"""

SHOW_EVENTS_QUERY = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      id
      name
      slug
      numEntrants
    }
  }
}"""

SHOW_SETS_QUERY = """query EventSets($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    tournament {
      id
      name
    }
    name
    sets(page: $page, perPage: 18, sortType: STANDARD) {
      nodes {
        fullRoundText
        games {
          winnerId
          selections {
            selectionValue
            entrant {
              id
            }
          }
        }
        id
        slots {
          standing {
            id
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
            participants {
              entrants {
                id
              }
              player {
                id
                gamerTag
                
              }
            }
          }
        }
        phaseGroup {
          id
          phase {
            name
          }
        }
      }
    }
  }
}"""


SHOW_ENTRANTS_QUERY = """query EventStandings($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    id
    name
    standings(query: {
      perPage: 25,
      page: $page}){
      nodes {
        placement
        entrant {
          id
          name
          participants {
            player {
              id
              gamerTag
            }
          }
          seeds {
            seedNum
          }
        }
      }
    }
  }
}"""

SHOW_EVENT_BRACKETS_QUERY = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      name
      slug
      phaseGroups {
        id
      }
    }
  }
}"""

SHOW_ENTRANT_SETS_QUERY = """query EventSets($eventId: ID!, $entrantId: ID!, $page: Int!) {
  event(id: $eventId) {
    sets(
      page: $page
      perPage: 16
      filters: {
        entrantIds: [$entrantId]
      }
    ) {
      nodes {
        id
        fullRoundText
        slots {
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
          }
        }
        phaseGroup {
          id
        }
      }
    }
  }
}"""

SHOW_EVENT_BY_GAME_SIZE_DATED_QUERY = """query TournamentsByVideogame($page: Int!, $videogameId: [ID!], $after: Timestamp!, $before: Timestamp!) {
  tournaments(query: {
    perPage: 32
    page: $page
    sortBy: "startAt asc"
    filter: {
      past: false
      videogameIds: $videogameId
      afterDate: $after
      beforeDate: $before
    }
  }) {
    nodes {
      name
      id
      slug
      isOnline
      startAt
      endAt
      events {
        name
        id
        numEntrants
        videogame {
          id
        }
      }
    }
  }
}"""

SHOW_LIGHTWEIGHT_RESULTS_QUERY = """query EventStandings($eventId: ID!, $page: Int!,) {
  event(id: $eventId) {
    standings(query: {
      perPage: 64,
      page: $page
    }){
      nodes {
        placement
        entrant {
          name
          id
        }
      }
    }
  }
}"""

SHOW_BY_COUNTRY_QUERY = """query TournamentsByCountry($countryCode: String!, $page: Int!) {
  tournaments(query: {
    perPage: 32,
    page: $page,
    sortBy: "startAt desc"
    filter: {
      countryCode: $countryCode
    }
  }) {
    nodes {
      id
      name
      slug
      numAttendees
      addrState
      city
      startAt
      endAt
      state
    }
  }
}"""

SHOW_BY_STATE_QUERY = """query TournamentsByState($state: String!, $page: Int!) {
  tournaments(query: {
    perPage: 32
    page: $page
    filter: {
      addrState: $state
    }
  }) {
    nodes {
      id
      name
      slug
      numAttendees
      city
      startAt
      endAt
      state
    }
  }
}"""

SHOW_BY_RADIUS_QUERY = """query ($page: Int, $coordinates: String!, $radius: String!) {
  tournaments(query: {
    page: $page
    perPage: 32
    filter: {
      location: {
        distanceFrom: $coordinates,
        distance: $radius
      }
    }
  }) {
    nodes {
      id
      name
      slug
      numAttendees
      countryCode
      addrState
      city
      startAt
      endAt
      state
    }
  }
}"""

SHOW_PLAYERS_BY_SPONSOR = """query ($slug:String!, $sponsor: String!) {
  tournament(slug: $slug) {
    participants(query: {
      filter: {
        search: {
          fieldsToSearch: ["prefix"],
          searchString: $sponsor
        }
      }
    }) {
      nodes {
        id
        gamerTag
        user {
          name
          location {
            country
            state
            city
          }
          player {
            id
          }
        }
      }
    }
  }
}"""

SHOW_BY_OWNER_QUERY = """query TournamentsByOwner($ownerId: ID!, $page: Int!) {
    tournaments(query: {
      perPage: 25,
      page: $page,
      filter: { ownerId: $ownerId }
    }) {
    nodes {
      id
      name
      slug
	  numAttendees
      countryCode
      addrState
      city
      startAt
      endAt
      state
    }
  }
}
"""


from pysmashgg import filters
from pysmashgg.b_queries import *
from pysmashgg.api import run_query

# Shows all the players in a bracket (aka phaseGroup)
def show_entrants(bracket_id, page_num, header, auto_retry):
    variables = {"phaseGroupId": bracket_id, "page": page_num}
    response = run_query(BRACKET_SHOW_ENTRANTS_QUERY, variables, header, auto_retry)
    data = filters.bracket_show_entrants_filter(response)
    return data

# Shows all the players in a bracket
def show_sets(bracket_id, page_num, header, auto_retry):
    variables = {"phaseGroupId": bracket_id, "page": page_num}
    response = run_query(BRACKET_SHOW_SETS_QUERY, variables, header, auto_retry)
    data = filters.bracket_show_sets_filter(response)
    return data

# THIS WAS MADE A SEPERATE FILE TO MAKE ROOM FOR FUTURE EXPANSION


import unittest
import os
import time
import pysmashgg

TOURNAMENT_SHOW_EVENT_ID_RESULT = 529399

TOURNAMENT_SHOW_RESULT = {'id': 253044, 'name': 'Smash Summit 10 Online', 'country': 'US', 'state': 'CA', 'city': 'Los Angeles', 'startTimestamp': 1605808800, 'endTimestamp': 1606111200, 'entrants': 68}

BRACKET_SHOW_ENTRANTS_RESULT = [{'entrantId': 6379759, 'tag': 'Zain', 'finalPlacement': 1, 'seed': 1, 'entrantPlayers': [{'playerId': 6126, 'playerTag': 'Zain'}]}, {'entrantId': 6379742, 'tag': 'C9 | Mang0', 'finalPlacement': 2, 'seed': 2, 'entrantPlayers': [{'playerId': 1000, 'playerTag': 'Mang0'}]}, {'entrantId': 6379744, 'tag': 'PG | iBDW', 'finalPlacement': 3, 'seed': 6, 'entrantPlayers': [{'playerId': 19554, 'playerTag': 'iBDW'}]}, {'entrantId': 6379747, 'tag': 'Envy | Wizzrobe', 'finalPlacement': 4, 'seed': 3, 'entrantPlayers': [{'playerId': 1028, 'playerTag': 'Wizzrobe'}]}, {'entrantId': 6379745, 'tag': 'UYU | n0ne', 'finalPlacement': 5, 'seed': 5, 'entrantPlayers': [{'playerId': 4107, 'playerTag': 'n0ne'}]}, {'entrantId': 6379751, 'tag': 'Ginger', 'finalPlacement': 5, 'seed': 7, 'entrantPlayers': [{'playerId': 3561, 'playerTag': 'Ginger'}]}, {'entrantId': 6379749, 'tag': 'Liquid | Hungrybox', 'finalPlacement': 7, 'seed': 4, 'entrantPlayers': [{'playerId': 1004, 'playerTag': 'Hungrybox'}]}, {'entrantId': 6379750, 'tag': 'S2J', 'finalPlacement': 7, 'seed': 8, 'entrantPlayers': [{'playerId': 1017, 'playerTag': 'S2J'}]}, {'entrantId': 6398729, 'tag': "Mango's Friend | Lucky", 'finalPlacement': 9, 'seed': 11, 'entrantPlayers': [{'playerId': 13932, 'playerTag': 'Lucky'}]}, {'entrantId': 6398726, 'tag': 'Soonsay', 'finalPlacement': 9, 'seed': 12, 'entrantPlayers': [{'playerId': 324561, 'playerTag': 'Soonsay'}]}, {'entrantId': 6379756, 'tag': 'CLG. | SFAT', 'finalPlacement': 9, 'seed': 15, 'entrantPlayers': [{'playerId': 1019, 'playerTag': 'SFAT'}]}, {'entrantId': 6379743, 'tag': 'IluZ | Spark', 'finalPlacement': 9, 'seed': 16, 'entrantPlayers': [{'playerId': 3357, 'playerTag': 'Spark'}]}, {'entrantId': 6379757, 'tag': 'EGtv | FatGoku', 'finalPlacement': 13, 'seed': 9, 'entrantPlayers': [{'playerId': 4518, 'playerTag': 'FatGoku'}]}, {'entrantId': 6398727, 'tag': 'Magi', 'finalPlacement': 13, 'seed': 10, 'entrantPlayers': [{'playerId': 6544, 'playerTag': 'Magi'}]}, {'entrantId': 6379746, 'tag': 'Captain Faceroll', 'finalPlacement': 13, 'seed': 13, 'entrantPlayers': [{'playerId': 3359, 'playerTag': 'Captain Faceroll'}]}, {'entrantId': 6379754, 'tag': 'Tempo | Axe', 'finalPlacement': 13, 'seed': 14, 'entrantPlayers': [{'playerId': 16342, 'playerTag': 'Axe'}]}]

PLAYER_SHOW_INFO_RESULT = {'tag': 'Mang0', 'name': 'Joseph Marquez', 'bio': 'Joseph Marquez', 'country': 'United States', 'state': 'CA', 'city': None, 'rankings': [{'title': 'Melee Stats: Summer 2018 - Fall 2018', 'rank': 6}, {'title': 'MPGR: 2019 MPGR', 'rank': 3}, {'title': 'SoCal: Fall 2019 Winter 2020', 'rank': 1}]}

EVENT_SHOW_HEAD_TO_HEAD_RESULT = [{'id': 33608659, 'entrant1Id': 6379759, 'entrant2Id': 6379742, 'entrant1Name': 'Zain', 'entrant2Name': 'C9 | Mang0', 'entrant1Score': 3, 'entrant2Score': 2, 'completed': True, 'winnerId': 6379759, 'loserId': 6379742, 'winnerName': 'Zain', 'loserName': 'C9 | Mang0', 'setRound': 'Grand Final', 'bracketId': 1401911}, {'id': 33608658, 'entrant1Id': 6379759, 'entrant2Id': 6379742, 'entrant1Name': 'Zain', 'entrant2Name': 'C9 | Mang0', 'entrant1Score': 3, 'entrant2Score': 1, 'completed': True, 'winnerId': 6379759, 'loserId': 6379742, 'winnerName': 'Zain', 'loserName': 'C9 | Mang0', 'setRound': 'Winners Final', 'bracketId': 1401911}]

LEAGUE_SHOW_RESULT = "{'id': 218787, 'name': 'TWT', 'startTimestamp': 1589666400, 'endTimestamp': 1589679000, 'games': None}"

class TestClass(unittest.TestCase):
    # Going to test specific calls and see if they work -- One from each
    smash = pysmashgg.SmashGG(os.environ.get('KEY'))

    def test_tournament_show_event_id(self):
        result = self.smash.tournament_show_event_id("smash-summit-10-online", "melee-singles")
        self.assertEqual(result, TOURNAMENT_SHOW_EVENT_ID_RESULT)

    def test_tournament_show(self):
        result = self.smash.tournament_show("smash-summit-10-online")
        self.assertEqual(result, TOURNAMENT_SHOW_RESULT)

    def test_bracket_show_entrants(self):
        result = self.smash.bracket_show_entrants(1401911, 1)
        self.assertEqual(result, BRACKET_SHOW_ENTRANTS_RESULT)

    def test_player_show_info(self):
        result = self.smash.player_show_info(1000)
        self.assertEqual(result, PLAYER_SHOW_INFO_RESULT)

    def test_event_show_head_to_head(self):
        result = self.smash.event_show_head_to_head(529399, "Mang0", "Zain")
        self.assertEqual(result, EVENT_SHOW_HEAD_TO_HEAD_RESULT)

    def test_league_show(self):
        result = self.smash.league_show("twt")
        self.assertEqual(result, LEAGUE_SHOW_RESULT)

if __name__ == '__main__':
    unittest.main()


import time
import requests
from pysmashgg.exceptions import *

# Runs queries
def run_query(query, variables, header, auto_retry):
    # This helper function is necessary for TooManyRequestsErrors
    def _run_query(query, variables, header, auto_retry, seconds): 
        json_request = {'query': query, 'variables': variables}
        try:
            request = requests.post(url='https://api.smash.gg/gql/alpha', json=json_request, headers=header)
            if request.status_code == 400:
                raise RequestError
            elif request.status_code == 429:
                raise TooManyRequestsError
            elif 400 <= request.status_code < 500:
                raise ResponseError
            elif 500 <= request.status_code < 600:
                raise ServerError
            elif 300 <= request.status_code < 400:
                raise NoIdeaError

            response = request.json()
            return response

        except RequestError:
            print("Error 400: Bad request (probably means your key is wrong)")
            return
        except TooManyRequestsError:
            if auto_retry:
                print("Error 429: Sending too many requests right now, trying again in {} seconds".format(seconds))
                time.sleep(seconds)
                return _run_query(query, variables, header, auto_retry, seconds*2)
            else:
                print("Error 429: Sending too many requests right now")
                return
        except ResponseError:
            print("Error {}: Unknown request error".format(request.status_code))
            return
        except ServerError:
            print("Error {}: Unknown server error".format(request.status_code))
            return
        except NoIdeaError:
            print("Error {}: I literally have no idea how you got this status code, please send this to me".format(request.status_code))
            return

    return _run_query(query, variables, header, auto_retry, 10)


import requests
from pysmashgg import exceptions, tournaments, brackets, players, events, leagues, api

class SmashGG(object):
    def __init__(self, key, auto_retry=True):
        self.key = key
        self.header = {"Authorization": "Bearer " + key}
        self.auto_retry = auto_retry
        
    def set_key_and_header(self, new_key):
        self.key = new_key
        self.header = {"Authorization": "Bearer " + new_key}

    # Sets automatic retry, a variable that says if run_query retries if too many requests
    def set_auto_retry(self, boo):
        self.auto_retry = boo

    def print_key(self):
        print(self.key)

    def print_header(self):
        print(self.header)

    def print_auto_retry(self):
        print(self.header)

    # Event_id for a tournament
    def tournament_show_event_id(self, tournament_name, event_name):
        return tournaments.get_event_id(tournament_name, event_name, self.header, self.auto_retry)

    # Metadata for a tournament
    def tournament_show(self, tournament_name):
        return tournaments.show(tournament_name, self.header, self.auto_retry)

    # Metadata for a tournament with a bracket
    def tournament_show_with_brackets(self, tournament_name, event_name):
        return tournaments.show_with_brackets(tournament_name, event_name, self.header, self.auto_retry)

    # Same as tournament_show_with_brackets but for all brackets
    def tournament_show_with_brackets_all(self, tournament_name):
        return tournaments.show_with_brackets_all(tournament_name, self.header, self.auto_retry)

    # List of events for a tournament
    def tournament_show_events(self, tournament_name):
        return tournaments.show_events(tournament_name, self.header, self.auto_retry)

    # List of sets for an event
    def tournament_show_sets(self, tournament_name, event_name, page_num):
        return tournaments.show_sets(tournament_name, event_name, page_num, self.header, self.auto_retry)

    # List of entrants for an event
    def tournament_show_entrants(self, tournament_name, event_name, page_num):
        return tournaments.show_entrants(tournament_name, event_name, page_num, self.header, self.auto_retry)
    
    # Bracket info for an event at a tournament
    def tournament_show_event_brackets(self, tournament_name, event_name):
        return tournaments.show_event_brackets(tournament_name, event_name, self.header, self.auto_retry)
    
    # Bracket info for all events at a tournament
    def tournament_show_all_event_brackets(self, tournament_name):
        return tournaments.show_all_event_brackets(tournament_name, self.header, self.auto_retry)

    # All sets from an entrant at an event
    def tournament_show_entrant_sets(self, tournament_name, event_name, entrant_name):
        return tournaments.show_entrant_sets(tournament_name, event_name, entrant_name, self.header, self.auto_retry)

    # All sets between two entrants at an event
    def tournament_show_head_to_head(self, tournament_name, event_name, entrant1_name, entrant2_name):
        return tournaments.show_head_to_head(tournament_name, event_name, entrant1_name, entrant2_name, self.header, self.auto_retry)

    # All tournaments with events (of a certain game) of a minimum size in between two unix timestamps
    def tournament_show_event_by_game_size_dated(self, num_entrants, videogame_id, after, before, page_num):
        return tournaments.show_event_by_game_size_dated(num_entrants, videogame_id, after, before, page_num, self.header, self.auto_retry)

    # Results of an event with only entrant name, id, and placement
    def tournament_show_lightweight_results(self, tournament_name, event_name, page_num):
        return tournaments.show_lightweight_results(tournament_name, event_name, page_num, self.header, self.auto_retry)

    # All tournaments by country (at least, as many at the API can display)
    def tournament_show_by_country(self, country_code, page_num):
        return tournaments.show_by_country(country_code, page_num, self.header, self.auto_retry)

    # All tournaments by US State
    def tournament_show_by_state(self, state_code, page_num):
        return tournaments.show_by_state(state_code, page_num, self.header, self.auto_retry)

    # All tournaments in a radius of a certain coordinate point
    def tournament_show_by_radius(self, coordinates, radius, page_num):
        return tournaments.show_by_radius(coordinates, radius, page_num, self.header, self.auto_retry)

    # Players from a tournament with a certain sponsor
    def tournament_show_players_by_sponsor(self, tournament_name, sponsor):
        return tournaments.show_players_by_sponsor(tournament_name, sponsor, self.header, self.auto_retry)
    
    # Tournaments by owner id
    def tournament_show_by_owner(self, owner, page_num):
        return tournaments.show_by_owner(owner, page_num, self.header, self.auto_retry)

    # All entrants in a bracket (phaseGroup) at a tournament
    def bracket_show_entrants(self, bracket_id, page_num):
        return brackets.show_entrants(bracket_id, page_num, self.header, self.auto_retry)

    # All sets in a bracket (phaseGroup) at a tournament
    def bracket_show_sets(self, bracket_id, page_num):
        return brackets.show_sets(bracket_id, page_num, self.header, self.auto_retry)

    # Player metadata
    def player_show_info(self, player_id):
        return players.show_info(player_id, self.header, self.auto_retry)

    # All tournaments by a player (where they registered with their smash.gg account)
    def player_show_tournaments(self, player_id, page_num):
        return players.show_tournaments(player_id, page_num, self.header, self.auto_retry)
    
    # All tournaments by a player for a certain game
    # Use https://docs.google.com/spreadsheets/d/1l-mcho90yDq4TWD-Y9A22oqFXGo8-gBDJP0eTmRpTaQ/
    # to find the game_id you're looking for
    def player_show_tournaments_for_game(self, player_id, player_name, videogame_id, page_num):
        return players.show_tournaments_for_game(player_id, player_name, videogame_id, page_num, self.header, self.auto_retry)

    # List of sets for an event
    def event_show_sets(self, event_id, page_num):
        return events.show_sets(event_id, page_num, self.header, self.auto_retry)

    # List of entrants for an event
    def event_show_entrants(self, event_id, page_num):
        return events.show_entrants(event_id, page_num, self.header, self.auto_retry)

    # All sets from an entrant at an event
    def event_show_entrant_sets(self, event_id, entrant_name):
        return events.show_entrant_sets(event_id, entrant_name, self.header, self.auto_retry)
    
    # All sets between two entrants at an event
    def event_show_head_to_head(self, event_id, entrant1_name, entrant2_name):
        return events.show_head_to_head(event_id, entrant1_name, entrant2_name, self.header, self.auto_retry)

    # Results of an event with only entrant name, id, and placement
    def event_show_lightweight_results(self, event_id, page_num):
        return events.show_lightweight_results(event_id, page_num, self.header, self.auto_retry)

    # Metadata for a league
    def league_show(self, league_name):
        return leagues.show(league_name, self.header, self.auto_retry)

    # League schedule (with events mainly, events at each tournament)
    def league_show_schedule(self, league_name, page_num):
        return leagues.show_schedule(league_name, page_num, self.header, self.auto_retry)
    
    # League standings
    def league_show_standings(self, league_name, page_num):
        return leagues.show_standings(league_name, page_num, self.header, self.auto_retry)


class TooManyRequestsError(Exception):
    # Means we're submitting too many requests
    pass

class ResponseError(Exception):
    # Unknown other error
    pass

class RequestError(Exception):
    # Bad request (normally means your key is wrong)
    pass

class ServerError(Exception):
    # Server error, not my fault
    pass

class NoIdeaError(Exception):
    # If you get this, please send this to me so I can figure it out lol
    pass


# Queries for players.py

PLAYER_SHOW_INFO_QUERY = """query ($playerId: ID!) {
  player(id: $playerId) {
    gamerTag
    user {
      name
      genderPronoun
      location {
        country
        state
        city
      }
    }
    rankings(videogameId: 1) {
      title
      rank
    }
  }
} """

PLAYER_SHOW_TOURNAMENTS_QUERY = """query ($playerId: ID!, $page: Int!) {
  player (id: $playerId) {
    user {
      tournaments (query: {perPage: 64, page: $page}) {
        nodes {
          name
          slug
          id
          numAttendees
          countryCode
          startAt
        }
      }
    }
  }
}"""

PLAYER_SHOW_TOURNAMENTS_FOR_GAME_QUERY = """query ($playerId: ID!, $playerName: String!, $videogameId: [ID!], $page: Int!) {
  player (id: $playerId) {
    user {
      tournaments (query: {perPage: 25, page: $page, filter: {videogameId: $videogameId}}) {
        nodes {
          name
          slug
          id
          numAttendees
          countryCode
          startAt
          events {
            name
            id
            slug
            numEntrants
            videogame {
              id
            }
            entrants (query: {filter: {name: $playerName}}) {
              nodes {
                id
              }
            }
          }
        }
      }
    }
  }
}"""


from pysmashgg import filters
from pysmashgg.t_queries import *
from pysmashgg.api import run_query

# HELPER FUNCTIONS

# Helper function to get playerId at an event
def get_player_id(event_id, player_name, header, auto_retry):
    variables = {"eventId": event_id, "name": player_name}
    response = run_query(PLAYER_ID_QUERY, variables, header, auto_retry)
    data = filters.player_id_filter(response, player_name)
    return data

# Helper function to get entrantId at an event
def get_entrant_id(event_id, player_name, header, auto_retry):
    variables = {"eventId": event_id, "name": player_name}
    response = run_query(ENTRANT_ID_QUERY, variables, header, auto_retry)
    data = response['data']['event']['entrants']['nodes'][0]['id']
    return data

# Helper function to get an eventId from a tournament
def get_event_id(tournament_name, event_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(EVENT_ID_QUERY, variables, header, auto_retry)
    data = filters.event_id_filter(response, event_name)
    return data

# ACTUAL FUNCTIONS

# Metadata for a tournament
def show(tournament_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_QUERY, variables, header, auto_retry)
    data = filters.show_filter(response)
    return data

# Metadata for a tournament with a specific brackets
def show_with_brackets(tournament_name, event_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_WITH_BRACKETS_QUERY, variables, header, auto_retry)
    data = filters.show_with_brackets_filter(response, event_name)
    return data

# Metadata for a tournament with all brackets
def show_with_brackets_all(tournament_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_WITH_BRACKETS_QUERY, variables, header, auto_retry)
    data = filters.show_with_brackets_all_filter(response)
    return data

# Shows all events from a tournaments
def show_events(tournament_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_EVENTS_QUERY, variables, header, auto_retry)
    data = filters.show_events_filter(response)
    return data

# Shows all the sets from an event 
def show_sets(tournament_name, event_name, page_num, header, auto_retry):
    event_id = get_event_id(tournament_name, event_name, header, auto_retry)
    variables = {"eventId": event_id, "page": page_num}
    response = run_query(SHOW_SETS_QUERY, variables, header, auto_retry)
    data = filters.show_sets_filter(response)
    return data
            
# Shows all entrants from a specific event
def show_entrants(tournament_name, event_name, page_num, header, auto_retry):
    event_id = get_event_id(tournament_name, event_name, header, auto_retry)
    variables = {"eventId": event_id, "page": page_num}
    response = run_query(SHOW_ENTRANTS_QUERY, variables, header, auto_retry)
    data = filters.show_entrants_filter(response)
    return data

# Shows all the event bracket IDs as well as the name and slug of the event
def show_event_brackets(tournament_name, event_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_EVENT_BRACKETS_QUERY, variables, header, auto_retry)
    data = filters.show_events_brackets_filter(response, event_name)
    return data

# Same as show_events_brackets but for all events at a tournament
def show_all_event_brackets(tournament_name, header, auto_retry):
    variables = {"tourneySlug": tournament_name}
    response = run_query(SHOW_EVENT_BRACKETS_QUERY, variables, header, auto_retry)
    data = filters.show_all_event_brackets_filter(response)
    return data

# Shows all entrant sets from a given event
def show_entrant_sets(tournament_name, event_name, entrant_name, header, auto_retry):
    event_id = get_event_id(tournament_name, event_name, header, auto_retry)
    entrant_id = get_entrant_id(event_id, entrant_name, header, auto_retry)
    variables = {"eventId": event_id, "entrantId": entrant_id, "page": 1}
    response = run_query(SHOW_ENTRANT_SETS_QUERY, variables, header, auto_retry)
    data = filters.show_entrant_sets_filter(response)
    return data

# Shows head to head at an event for two given entrants
def show_head_to_head(tournament_name, event_name, entrant1_name, entrant2_name, header, auto_retry):
    event_id = get_event_id(tournament_name, event_name, header, auto_retry)
    entrant1_id = get_entrant_id(event_id, entrant1_name, header, auto_retry)
    variables = {"eventId": event_id, "entrantId": entrant1_id, "page": 1}
    response = run_query(SHOW_ENTRANT_SETS_QUERY, variables, header, auto_retry)
    data = filters.show_head_to_head_filter(response, entrant2_name)
    return data

# Shows all events (of a certain game) of a minimum size in between two unix timestamps
def show_event_by_game_size_dated(num_entrants, videogame_id, after, before, page_num, header, auto_retry):
    variables = {"videogameId": videogame_id, "after": after, "before": before, "page": page_num}
    response = run_query(SHOW_EVENT_BY_GAME_SIZE_DATED_QUERY, variables, header, auto_retry)
    data = filters.show_event_by_game_size_dated_filter(response, num_entrants, videogame_id)
    return data

# Shows the results of an event with only entrant name, id, and placement
def show_lightweight_results(tournament_name, event_name, page_num, header, auto_retry):
    event_id = get_event_id(tournament_name, event_name, header, auto_retry)
    variables = {"eventId": event_id, "page": page_num}
    response = run_query(SHOW_LIGHTWEIGHT_RESULTS_QUERY, variables, header, auto_retry)
    data = filters.show_lightweight_results_filter(response)
    return data

# Shows a list of tournaments by country
def show_by_country(country_code, page_num, header, auto_retry):
    variables = {"countryCode": country_code, "page": page_num}
    response = run_query(SHOW_BY_COUNTRY_QUERY, variables, header, auto_retry)
    data = filters.show_by_country_filter(response)
    return data

# Shows a list of tournaments by US State
def show_by_state(state_code, page_num, header, auto_retry):
    variables = {"state": state_code, "page": page_num}
    response = run_query(SHOW_BY_STATE_QUERY, variables, header, auto_retry)
    data = filters.show_by_state_filter(response)
    return data

# Shows a list of tournaments from a certain point within a radius
def show_by_radius(coordinates, radius, page_num, header, auto_retry):
    variables = {"coordinates": coordinates, "radius": radius, "page": page_num}
    response = run_query(SHOW_BY_RADIUS_QUERY, variables, header, auto_retry)
    data = filters.show_by_radius_filter(response)
    return data

# Shows a list of players at a tournament by their sponsor
def show_players_by_sponsor(tournament_name, sponsor, header, auto_retry):
    variables = {"slug": tournament_name, "sponsor": sponsor}
    response = run_query(SHOW_PLAYERS_BY_SPONSOR, variables, header, auto_retry)
    data = filters.show_players_by_sponsor_filter(response)
    return data

def show_by_owner(owner, page_num, header, auto_retry):
    variables = {"ownerId": owner, "page": page_num}
    response = run_query(SHOW_BY_OWNER_QUERY, variables, header, auto_retry)
    data = filters.show_by_owner_filter(response)
    return data


# Queries for leagues.py

SHOW_QUERY = """query ($slug: String!){
  league(slug: $slug) {
    id
    name
    startAt
    endAt
    videogames {
      displayName
      id
    }
  }
}"""

SHOW_SCHEDULE_QUERY = """query LeagueSchedule ($slug: String!, $page: Int!){
  league(slug: $slug) {
    id
    name
    events(query: {
      page: $page,
      perPage: 20
    }) {
      nodes {
        id
        name
        slug
        startAt
        numEntrants
        tournament {
          id
          name
          slug
        }
      }
    }
  }
}"""

SHOW_STANDINGS_QUERY = """query LeagueStandings ($slug: String!, $page: Int!){
  league(slug: $slug) {
    standings (query: {
      page: $page,
      perPage: 25
    }) {
      nodes {
        id
        placement
        player {
          id
          gamerTag
        }
      }
    }
  }
}"""